"""
astLib - python astronomy modules

(c) 2007-2012 Matt Hilton

(c) 2013-2020 Matt Hilton & Steven Boada

U{http://astlib.sourceforge.net}

See the README file for information on usage and installation.
See the LICENSE file for information on distribution.

"""

__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS', 'astSED']
__version__ = '0.11.5'



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 2.0.7
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.



from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_wcs', [dirname(__file__)])
        except ImportError:
            import _wcs
            return _wcs
        if fp is not None:
            try:
                _mod = imp.load_module('_wcs', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _wcs = swig_import_helper()
    del swig_import_helper
else:
    import _wcs
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0



def new_doubleArray(*args):
  """new_doubleArray(nelements) -> double *"""
  return _wcs.new_doubleArray(*args)

def delete_doubleArray(*args):
  """delete_doubleArray(ary)"""
  return _wcs.delete_doubleArray(*args)

def doubleArray_getitem(*args):
  """doubleArray_getitem(ary, index) -> double"""
  return _wcs.doubleArray_getitem(*args)

def doubleArray_setitem(*args):
  """doubleArray_setitem(ary, index, value)"""
  return _wcs.doubleArray_setitem(*args)

def wcsinit(*args):
  """wcsinit(hstring) -> WorldCoor"""
  return _wcs.wcsinit(*args)

def wcsxinit(*args):
  """wcsxinit(cra, cdec, secpix, xrpix, yrpix, nxpix, nypix, rotate, equinox, epoch, proj) -> WorldCoor"""
  return _wcs.wcsxinit(*args)

def wcskinit(*args):
  """
    wcskinit(nxpix, nypix, ctype1, ctype2, crpix1, crpix2, crval1, crval2, cd, cdelt1, cdelt2, 
        crota, equinox, epoch) -> WorldCoor
    """
  return _wcs.wcskinit(*args)

def iswcs(*args):
  """iswcs(wcs) -> int"""
  return _wcs.iswcs(*args)

def nowcs(*args):
  """nowcs(wcs) -> int"""
  return _wcs.nowcs(*args)

def wcs2pix(*args):
  """wcs2pix(wcs, xpos, ypos)"""
  return _wcs.wcs2pix(*args)

def pix2wcs(*args):
  """pix2wcs(wcs, xpix, ypix)"""
  return _wcs.pix2wcs(*args)

def wcscent(*args):
  """wcscent(wcs)"""
  return _wcs.wcscent(*args)

def getradecsys(*args):
  """getradecsys(wcs) -> char *"""
  return _wcs.getradecsys(*args)

def wcsoutinit(*args):
  """wcsoutinit(wcs, coorsys)"""
  return _wcs.wcsoutinit(*args)

def wcsininit(*args):
  """wcsininit(wcs, coorsys)"""
  return _wcs.wcsininit(*args)

def getwcsout(*args):
  """getwcsout(wcs) -> char *"""
  return _wcs.getwcsout(*args)

def getwcsin(*args):
  """getwcsin(wcs) -> char *"""
  return _wcs.getwcsin(*args)

def wcssize(*args):
  """wcssize(wcs)"""
  return _wcs.wcssize(*args)

def wcsfull(*args):
  """wcsfull(wcs)"""
  return _wcs.wcsfull(*args)
class WorldCoor(_object):
    """Proxy of C WorldCoor struct"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, WorldCoor, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, WorldCoor, name)
    __repr__ = _swig_repr
    __swig_setmethods__["xref"] = _wcs.WorldCoor_xref_set
    __swig_getmethods__["xref"] = _wcs.WorldCoor_xref_get
    if _newclass:xref = _swig_property(_wcs.WorldCoor_xref_get, _wcs.WorldCoor_xref_set)
    __swig_setmethods__["yref"] = _wcs.WorldCoor_yref_set
    __swig_getmethods__["yref"] = _wcs.WorldCoor_yref_get
    if _newclass:yref = _swig_property(_wcs.WorldCoor_yref_get, _wcs.WorldCoor_yref_set)
    __swig_setmethods__["xrefpix"] = _wcs.WorldCoor_xrefpix_set
    __swig_getmethods__["xrefpix"] = _wcs.WorldCoor_xrefpix_get
    if _newclass:xrefpix = _swig_property(_wcs.WorldCoor_xrefpix_get, _wcs.WorldCoor_xrefpix_set)
    __swig_setmethods__["yrefpix"] = _wcs.WorldCoor_yrefpix_set
    __swig_getmethods__["yrefpix"] = _wcs.WorldCoor_yrefpix_get
    if _newclass:yrefpix = _swig_property(_wcs.WorldCoor_yrefpix_get, _wcs.WorldCoor_yrefpix_set)
    __swig_setmethods__["xinc"] = _wcs.WorldCoor_xinc_set
    __swig_getmethods__["xinc"] = _wcs.WorldCoor_xinc_get
    if _newclass:xinc = _swig_property(_wcs.WorldCoor_xinc_get, _wcs.WorldCoor_xinc_set)
    __swig_setmethods__["yinc"] = _wcs.WorldCoor_yinc_set
    __swig_getmethods__["yinc"] = _wcs.WorldCoor_yinc_get
    if _newclass:yinc = _swig_property(_wcs.WorldCoor_yinc_get, _wcs.WorldCoor_yinc_set)
    __swig_setmethods__["rot"] = _wcs.WorldCoor_rot_set
    __swig_getmethods__["rot"] = _wcs.WorldCoor_rot_get
    if _newclass:rot = _swig_property(_wcs.WorldCoor_rot_get, _wcs.WorldCoor_rot_set)
    __swig_setmethods__["cd"] = _wcs.WorldCoor_cd_set
    __swig_getmethods__["cd"] = _wcs.WorldCoor_cd_get
    if _newclass:cd = _swig_property(_wcs.WorldCoor_cd_get, _wcs.WorldCoor_cd_set)
    __swig_setmethods__["dc"] = _wcs.WorldCoor_dc_set
    __swig_getmethods__["dc"] = _wcs.WorldCoor_dc_get
    if _newclass:dc = _swig_property(_wcs.WorldCoor_dc_get, _wcs.WorldCoor_dc_set)
    __swig_setmethods__["equinox"] = _wcs.WorldCoor_equinox_set
    __swig_getmethods__["equinox"] = _wcs.WorldCoor_equinox_get
    if _newclass:equinox = _swig_property(_wcs.WorldCoor_equinox_get, _wcs.WorldCoor_equinox_set)
    __swig_setmethods__["epoch"] = _wcs.WorldCoor_epoch_set
    __swig_getmethods__["epoch"] = _wcs.WorldCoor_epoch_get
    if _newclass:epoch = _swig_property(_wcs.WorldCoor_epoch_get, _wcs.WorldCoor_epoch_set)
    __swig_setmethods__["nxpix"] = _wcs.WorldCoor_nxpix_set
    __swig_getmethods__["nxpix"] = _wcs.WorldCoor_nxpix_get
    if _newclass:nxpix = _swig_property(_wcs.WorldCoor_nxpix_get, _wcs.WorldCoor_nxpix_set)
    __swig_setmethods__["nypix"] = _wcs.WorldCoor_nypix_set
    __swig_getmethods__["nypix"] = _wcs.WorldCoor_nypix_get
    if _newclass:nypix = _swig_property(_wcs.WorldCoor_nypix_get, _wcs.WorldCoor_nypix_set)
    __swig_setmethods__["plate_ra"] = _wcs.WorldCoor_plate_ra_set
    __swig_getmethods__["plate_ra"] = _wcs.WorldCoor_plate_ra_get
    if _newclass:plate_ra = _swig_property(_wcs.WorldCoor_plate_ra_get, _wcs.WorldCoor_plate_ra_set)
    __swig_setmethods__["plate_dec"] = _wcs.WorldCoor_plate_dec_set
    __swig_getmethods__["plate_dec"] = _wcs.WorldCoor_plate_dec_get
    if _newclass:plate_dec = _swig_property(_wcs.WorldCoor_plate_dec_get, _wcs.WorldCoor_plate_dec_set)
    __swig_setmethods__["plate_scale"] = _wcs.WorldCoor_plate_scale_set
    __swig_getmethods__["plate_scale"] = _wcs.WorldCoor_plate_scale_get
    if _newclass:plate_scale = _swig_property(_wcs.WorldCoor_plate_scale_get, _wcs.WorldCoor_plate_scale_set)
    __swig_setmethods__["x_pixel_offset"] = _wcs.WorldCoor_x_pixel_offset_set
    __swig_getmethods__["x_pixel_offset"] = _wcs.WorldCoor_x_pixel_offset_get
    if _newclass:x_pixel_offset = _swig_property(_wcs.WorldCoor_x_pixel_offset_get, _wcs.WorldCoor_x_pixel_offset_set)
    __swig_setmethods__["y_pixel_offset"] = _wcs.WorldCoor_y_pixel_offset_set
    __swig_getmethods__["y_pixel_offset"] = _wcs.WorldCoor_y_pixel_offset_get
    if _newclass:y_pixel_offset = _swig_property(_wcs.WorldCoor_y_pixel_offset_get, _wcs.WorldCoor_y_pixel_offset_set)
    __swig_setmethods__["x_pixel_size"] = _wcs.WorldCoor_x_pixel_size_set
    __swig_getmethods__["x_pixel_size"] = _wcs.WorldCoor_x_pixel_size_get
    if _newclass:x_pixel_size = _swig_property(_wcs.WorldCoor_x_pixel_size_get, _wcs.WorldCoor_x_pixel_size_set)
    __swig_setmethods__["y_pixel_size"] = _wcs.WorldCoor_y_pixel_size_set
    __swig_getmethods__["y_pixel_size"] = _wcs.WorldCoor_y_pixel_size_get
    if _newclass:y_pixel_size = _swig_property(_wcs.WorldCoor_y_pixel_size_get, _wcs.WorldCoor_y_pixel_size_set)
    __swig_setmethods__["ppo_coeff"] = _wcs.WorldCoor_ppo_coeff_set
    __swig_getmethods__["ppo_coeff"] = _wcs.WorldCoor_ppo_coeff_get
    if _newclass:ppo_coeff = _swig_property(_wcs.WorldCoor_ppo_coeff_get, _wcs.WorldCoor_ppo_coeff_set)
    __swig_setmethods__["x_coeff"] = _wcs.WorldCoor_x_coeff_set
    __swig_getmethods__["x_coeff"] = _wcs.WorldCoor_x_coeff_get
    if _newclass:x_coeff = _swig_property(_wcs.WorldCoor_x_coeff_get, _wcs.WorldCoor_x_coeff_set)
    __swig_setmethods__["y_coeff"] = _wcs.WorldCoor_y_coeff_set
    __swig_getmethods__["y_coeff"] = _wcs.WorldCoor_y_coeff_get
    if _newclass:y_coeff = _swig_property(_wcs.WorldCoor_y_coeff_get, _wcs.WorldCoor_y_coeff_set)
    __swig_setmethods__["xpix"] = _wcs.WorldCoor_xpix_set
    __swig_getmethods__["xpix"] = _wcs.WorldCoor_xpix_get
    if _newclass:xpix = _swig_property(_wcs.WorldCoor_xpix_get, _wcs.WorldCoor_xpix_set)
    __swig_setmethods__["ypix"] = _wcs.WorldCoor_ypix_set
    __swig_getmethods__["ypix"] = _wcs.WorldCoor_ypix_get
    if _newclass:ypix = _swig_property(_wcs.WorldCoor_ypix_get, _wcs.WorldCoor_ypix_set)
    __swig_setmethods__["zpix"] = _wcs.WorldCoor_zpix_set
    __swig_getmethods__["zpix"] = _wcs.WorldCoor_zpix_get
    if _newclass:zpix = _swig_property(_wcs.WorldCoor_zpix_get, _wcs.WorldCoor_zpix_set)
    __swig_setmethods__["xpos"] = _wcs.WorldCoor_xpos_set
    __swig_getmethods__["xpos"] = _wcs.WorldCoor_xpos_get
    if _newclass:xpos = _swig_property(_wcs.WorldCoor_xpos_get, _wcs.WorldCoor_xpos_set)
    __swig_setmethods__["ypos"] = _wcs.WorldCoor_ypos_set
    __swig_getmethods__["ypos"] = _wcs.WorldCoor_ypos_get
    if _newclass:ypos = _swig_property(_wcs.WorldCoor_ypos_get, _wcs.WorldCoor_ypos_set)
    __swig_setmethods__["crpix"] = _wcs.WorldCoor_crpix_set
    __swig_getmethods__["crpix"] = _wcs.WorldCoor_crpix_get
    if _newclass:crpix = _swig_property(_wcs.WorldCoor_crpix_get, _wcs.WorldCoor_crpix_set)
    __swig_setmethods__["crval"] = _wcs.WorldCoor_crval_set
    __swig_getmethods__["crval"] = _wcs.WorldCoor_crval_get
    if _newclass:crval = _swig_property(_wcs.WorldCoor_crval_get, _wcs.WorldCoor_crval_set)
    __swig_setmethods__["cdelt"] = _wcs.WorldCoor_cdelt_set
    __swig_getmethods__["cdelt"] = _wcs.WorldCoor_cdelt_get
    if _newclass:cdelt = _swig_property(_wcs.WorldCoor_cdelt_get, _wcs.WorldCoor_cdelt_set)
    __swig_setmethods__["pc"] = _wcs.WorldCoor_pc_set
    __swig_getmethods__["pc"] = _wcs.WorldCoor_pc_get
    if _newclass:pc = _swig_property(_wcs.WorldCoor_pc_get, _wcs.WorldCoor_pc_set)
    __swig_setmethods__["projp"] = _wcs.WorldCoor_projp_set
    __swig_getmethods__["projp"] = _wcs.WorldCoor_projp_get
    if _newclass:projp = _swig_property(_wcs.WorldCoor_projp_get, _wcs.WorldCoor_projp_set)
    __swig_setmethods__["pvfail"] = _wcs.WorldCoor_pvfail_set
    __swig_getmethods__["pvfail"] = _wcs.WorldCoor_pvfail_get
    if _newclass:pvfail = _swig_property(_wcs.WorldCoor_pvfail_get, _wcs.WorldCoor_pvfail_set)
    __swig_setmethods__["projppv"] = _wcs.WorldCoor_projppv_set
    __swig_getmethods__["projppv"] = _wcs.WorldCoor_projppv_get
    if _newclass:projppv = _swig_property(_wcs.WorldCoor_projppv_get, _wcs.WorldCoor_projppv_set)
    __swig_setmethods__["inv_x"] = _wcs.WorldCoor_inv_x_set
    __swig_getmethods__["inv_x"] = _wcs.WorldCoor_inv_x_get
    if _newclass:inv_x = _swig_property(_wcs.WorldCoor_inv_x_get, _wcs.WorldCoor_inv_x_set)
    __swig_setmethods__["inv_y"] = _wcs.WorldCoor_inv_y_set
    __swig_getmethods__["inv_y"] = _wcs.WorldCoor_inv_y_get
    if _newclass:inv_y = _swig_property(_wcs.WorldCoor_inv_y_get, _wcs.WorldCoor_inv_y_set)
    __swig_setmethods__["longpole"] = _wcs.WorldCoor_longpole_set
    __swig_getmethods__["longpole"] = _wcs.WorldCoor_longpole_get
    if _newclass:longpole = _swig_property(_wcs.WorldCoor_longpole_get, _wcs.WorldCoor_longpole_set)
    __swig_setmethods__["latpole"] = _wcs.WorldCoor_latpole_set
    __swig_getmethods__["latpole"] = _wcs.WorldCoor_latpole_get
    if _newclass:latpole = _swig_property(_wcs.WorldCoor_latpole_get, _wcs.WorldCoor_latpole_set)
    __swig_setmethods__["rodeg"] = _wcs.WorldCoor_rodeg_set
    __swig_getmethods__["rodeg"] = _wcs.WorldCoor_rodeg_get
    if _newclass:rodeg = _swig_property(_wcs.WorldCoor_rodeg_get, _wcs.WorldCoor_rodeg_set)
    __swig_setmethods__["imrot"] = _wcs.WorldCoor_imrot_set
    __swig_getmethods__["imrot"] = _wcs.WorldCoor_imrot_get
    if _newclass:imrot = _swig_property(_wcs.WorldCoor_imrot_get, _wcs.WorldCoor_imrot_set)
    __swig_setmethods__["pa_north"] = _wcs.WorldCoor_pa_north_set
    __swig_getmethods__["pa_north"] = _wcs.WorldCoor_pa_north_get
    if _newclass:pa_north = _swig_property(_wcs.WorldCoor_pa_north_get, _wcs.WorldCoor_pa_north_set)
    __swig_setmethods__["pa_east"] = _wcs.WorldCoor_pa_east_set
    __swig_getmethods__["pa_east"] = _wcs.WorldCoor_pa_east_get
    if _newclass:pa_east = _swig_property(_wcs.WorldCoor_pa_east_get, _wcs.WorldCoor_pa_east_set)
    __swig_setmethods__["radvel"] = _wcs.WorldCoor_radvel_set
    __swig_getmethods__["radvel"] = _wcs.WorldCoor_radvel_get
    if _newclass:radvel = _swig_property(_wcs.WorldCoor_radvel_get, _wcs.WorldCoor_radvel_set)
    __swig_setmethods__["zvel"] = _wcs.WorldCoor_zvel_set
    __swig_getmethods__["zvel"] = _wcs.WorldCoor_zvel_get
    if _newclass:zvel = _swig_property(_wcs.WorldCoor_zvel_get, _wcs.WorldCoor_zvel_set)
    __swig_setmethods__["zpzd"] = _wcs.WorldCoor_zpzd_set
    __swig_getmethods__["zpzd"] = _wcs.WorldCoor_zpzd_get
    if _newclass:zpzd = _swig_property(_wcs.WorldCoor_zpzd_get, _wcs.WorldCoor_zpzd_set)
    __swig_setmethods__["zpr"] = _wcs.WorldCoor_zpr_set
    __swig_getmethods__["zpr"] = _wcs.WorldCoor_zpr_get
    if _newclass:zpr = _swig_property(_wcs.WorldCoor_zpr_get, _wcs.WorldCoor_zpr_set)
    __swig_setmethods__["imflip"] = _wcs.WorldCoor_imflip_set
    __swig_getmethods__["imflip"] = _wcs.WorldCoor_imflip_get
    if _newclass:imflip = _swig_property(_wcs.WorldCoor_imflip_get, _wcs.WorldCoor_imflip_set)
    __swig_setmethods__["prjcode"] = _wcs.WorldCoor_prjcode_set
    __swig_getmethods__["prjcode"] = _wcs.WorldCoor_prjcode_get
    if _newclass:prjcode = _swig_property(_wcs.WorldCoor_prjcode_get, _wcs.WorldCoor_prjcode_set)
    __swig_setmethods__["latbase"] = _wcs.WorldCoor_latbase_set
    __swig_getmethods__["latbase"] = _wcs.WorldCoor_latbase_get
    if _newclass:latbase = _swig_property(_wcs.WorldCoor_latbase_get, _wcs.WorldCoor_latbase_set)
    __swig_setmethods__["ncoeff1"] = _wcs.WorldCoor_ncoeff1_set
    __swig_getmethods__["ncoeff1"] = _wcs.WorldCoor_ncoeff1_get
    if _newclass:ncoeff1 = _swig_property(_wcs.WorldCoor_ncoeff1_get, _wcs.WorldCoor_ncoeff1_set)
    __swig_setmethods__["ncoeff2"] = _wcs.WorldCoor_ncoeff2_set
    __swig_getmethods__["ncoeff2"] = _wcs.WorldCoor_ncoeff2_get
    if _newclass:ncoeff2 = _swig_property(_wcs.WorldCoor_ncoeff2_get, _wcs.WorldCoor_ncoeff2_set)
    __swig_setmethods__["zpnp"] = _wcs.WorldCoor_zpnp_set
    __swig_getmethods__["zpnp"] = _wcs.WorldCoor_zpnp_get
    if _newclass:zpnp = _swig_property(_wcs.WorldCoor_zpnp_get, _wcs.WorldCoor_zpnp_set)
    __swig_setmethods__["changesys"] = _wcs.WorldCoor_changesys_set
    __swig_getmethods__["changesys"] = _wcs.WorldCoor_changesys_get
    if _newclass:changesys = _swig_property(_wcs.WorldCoor_changesys_get, _wcs.WorldCoor_changesys_set)
    __swig_setmethods__["printsys"] = _wcs.WorldCoor_printsys_set
    __swig_getmethods__["printsys"] = _wcs.WorldCoor_printsys_get
    if _newclass:printsys = _swig_property(_wcs.WorldCoor_printsys_get, _wcs.WorldCoor_printsys_set)
    __swig_setmethods__["ndec"] = _wcs.WorldCoor_ndec_set
    __swig_getmethods__["ndec"] = _wcs.WorldCoor_ndec_get
    if _newclass:ndec = _swig_property(_wcs.WorldCoor_ndec_get, _wcs.WorldCoor_ndec_set)
    __swig_setmethods__["degout"] = _wcs.WorldCoor_degout_set
    __swig_getmethods__["degout"] = _wcs.WorldCoor_degout_get
    if _newclass:degout = _swig_property(_wcs.WorldCoor_degout_get, _wcs.WorldCoor_degout_set)
    __swig_setmethods__["tabsys"] = _wcs.WorldCoor_tabsys_set
    __swig_getmethods__["tabsys"] = _wcs.WorldCoor_tabsys_get
    if _newclass:tabsys = _swig_property(_wcs.WorldCoor_tabsys_get, _wcs.WorldCoor_tabsys_set)
    __swig_setmethods__["rotmat"] = _wcs.WorldCoor_rotmat_set
    __swig_getmethods__["rotmat"] = _wcs.WorldCoor_rotmat_get
    if _newclass:rotmat = _swig_property(_wcs.WorldCoor_rotmat_get, _wcs.WorldCoor_rotmat_set)
    __swig_setmethods__["coorflip"] = _wcs.WorldCoor_coorflip_set
    __swig_getmethods__["coorflip"] = _wcs.WorldCoor_coorflip_get
    if _newclass:coorflip = _swig_property(_wcs.WorldCoor_coorflip_get, _wcs.WorldCoor_coorflip_set)
    __swig_setmethods__["offscl"] = _wcs.WorldCoor_offscl_set
    __swig_getmethods__["offscl"] = _wcs.WorldCoor_offscl_get
    if _newclass:offscl = _swig_property(_wcs.WorldCoor_offscl_get, _wcs.WorldCoor_offscl_set)
    __swig_setmethods__["wcson"] = _wcs.WorldCoor_wcson_set
    __swig_getmethods__["wcson"] = _wcs.WorldCoor_wcson_get
    if _newclass:wcson = _swig_property(_wcs.WorldCoor_wcson_get, _wcs.WorldCoor_wcson_set)
    __swig_setmethods__["naxis"] = _wcs.WorldCoor_naxis_set
    __swig_getmethods__["naxis"] = _wcs.WorldCoor_naxis_get
    if _newclass:naxis = _swig_property(_wcs.WorldCoor_naxis_get, _wcs.WorldCoor_naxis_set)
    __swig_setmethods__["naxes"] = _wcs.WorldCoor_naxes_set
    __swig_getmethods__["naxes"] = _wcs.WorldCoor_naxes_get
    if _newclass:naxes = _swig_property(_wcs.WorldCoor_naxes_get, _wcs.WorldCoor_naxes_set)
    __swig_setmethods__["wcsproj"] = _wcs.WorldCoor_wcsproj_set
    __swig_getmethods__["wcsproj"] = _wcs.WorldCoor_wcsproj_get
    if _newclass:wcsproj = _swig_property(_wcs.WorldCoor_wcsproj_get, _wcs.WorldCoor_wcsproj_set)
    __swig_setmethods__["linmode"] = _wcs.WorldCoor_linmode_set
    __swig_getmethods__["linmode"] = _wcs.WorldCoor_linmode_get
    if _newclass:linmode = _swig_property(_wcs.WorldCoor_linmode_get, _wcs.WorldCoor_linmode_set)
    __swig_setmethods__["detector"] = _wcs.WorldCoor_detector_set
    __swig_getmethods__["detector"] = _wcs.WorldCoor_detector_get
    if _newclass:detector = _swig_property(_wcs.WorldCoor_detector_get, _wcs.WorldCoor_detector_set)
    __swig_setmethods__["instrument"] = _wcs.WorldCoor_instrument_set
    __swig_getmethods__["instrument"] = _wcs.WorldCoor_instrument_get
    if _newclass:instrument = _swig_property(_wcs.WorldCoor_instrument_get, _wcs.WorldCoor_instrument_set)
    __swig_setmethods__["ctype"] = _wcs.WorldCoor_ctype_set
    __swig_getmethods__["ctype"] = _wcs.WorldCoor_ctype_get
    if _newclass:ctype = _swig_property(_wcs.WorldCoor_ctype_get, _wcs.WorldCoor_ctype_set)
    __swig_setmethods__["c1type"] = _wcs.WorldCoor_c1type_set
    __swig_getmethods__["c1type"] = _wcs.WorldCoor_c1type_get
    if _newclass:c1type = _swig_property(_wcs.WorldCoor_c1type_get, _wcs.WorldCoor_c1type_set)
    __swig_setmethods__["c2type"] = _wcs.WorldCoor_c2type_set
    __swig_getmethods__["c2type"] = _wcs.WorldCoor_c2type_get
    if _newclass:c2type = _swig_property(_wcs.WorldCoor_c2type_get, _wcs.WorldCoor_c2type_set)
    __swig_setmethods__["ptype"] = _wcs.WorldCoor_ptype_set
    __swig_getmethods__["ptype"] = _wcs.WorldCoor_ptype_get
    if _newclass:ptype = _swig_property(_wcs.WorldCoor_ptype_get, _wcs.WorldCoor_ptype_set)
    __swig_setmethods__["units"] = _wcs.WorldCoor_units_set
    __swig_getmethods__["units"] = _wcs.WorldCoor_units_get
    if _newclass:units = _swig_property(_wcs.WorldCoor_units_get, _wcs.WorldCoor_units_set)
    __swig_setmethods__["radecsys"] = _wcs.WorldCoor_radecsys_set
    __swig_getmethods__["radecsys"] = _wcs.WorldCoor_radecsys_get
    if _newclass:radecsys = _swig_property(_wcs.WorldCoor_radecsys_get, _wcs.WorldCoor_radecsys_set)
    __swig_setmethods__["radecout"] = _wcs.WorldCoor_radecout_set
    __swig_getmethods__["radecout"] = _wcs.WorldCoor_radecout_get
    if _newclass:radecout = _swig_property(_wcs.WorldCoor_radecout_get, _wcs.WorldCoor_radecout_set)
    __swig_setmethods__["radecin"] = _wcs.WorldCoor_radecin_set
    __swig_getmethods__["radecin"] = _wcs.WorldCoor_radecin_get
    if _newclass:radecin = _swig_property(_wcs.WorldCoor_radecin_get, _wcs.WorldCoor_radecin_set)
    __swig_setmethods__["eqin"] = _wcs.WorldCoor_eqin_set
    __swig_getmethods__["eqin"] = _wcs.WorldCoor_eqin_get
    if _newclass:eqin = _swig_property(_wcs.WorldCoor_eqin_get, _wcs.WorldCoor_eqin_set)
    __swig_setmethods__["eqout"] = _wcs.WorldCoor_eqout_set
    __swig_getmethods__["eqout"] = _wcs.WorldCoor_eqout_get
    if _newclass:eqout = _swig_property(_wcs.WorldCoor_eqout_get, _wcs.WorldCoor_eqout_set)
    __swig_setmethods__["sysin"] = _wcs.WorldCoor_sysin_set
    __swig_getmethods__["sysin"] = _wcs.WorldCoor_sysin_get
    if _newclass:sysin = _swig_property(_wcs.WorldCoor_sysin_get, _wcs.WorldCoor_sysin_set)
    __swig_setmethods__["syswcs"] = _wcs.WorldCoor_syswcs_set
    __swig_getmethods__["syswcs"] = _wcs.WorldCoor_syswcs_get
    if _newclass:syswcs = _swig_property(_wcs.WorldCoor_syswcs_get, _wcs.WorldCoor_syswcs_set)
    __swig_setmethods__["sysout"] = _wcs.WorldCoor_sysout_set
    __swig_getmethods__["sysout"] = _wcs.WorldCoor_sysout_get
    if _newclass:sysout = _swig_property(_wcs.WorldCoor_sysout_get, _wcs.WorldCoor_sysout_set)
    __swig_setmethods__["center"] = _wcs.WorldCoor_center_set
    __swig_getmethods__["center"] = _wcs.WorldCoor_center_get
    if _newclass:center = _swig_property(_wcs.WorldCoor_center_get, _wcs.WorldCoor_center_set)
    __swig_setmethods__["wcsl"] = _wcs.WorldCoor_wcsl_set
    __swig_getmethods__["wcsl"] = _wcs.WorldCoor_wcsl_get
    if _newclass:wcsl = _swig_property(_wcs.WorldCoor_wcsl_get, _wcs.WorldCoor_wcsl_set)
    __swig_setmethods__["lin"] = _wcs.WorldCoor_lin_set
    __swig_getmethods__["lin"] = _wcs.WorldCoor_lin_get
    if _newclass:lin = _swig_property(_wcs.WorldCoor_lin_get, _wcs.WorldCoor_lin_set)
    __swig_setmethods__["cel"] = _wcs.WorldCoor_cel_set
    __swig_getmethods__["cel"] = _wcs.WorldCoor_cel_get
    if _newclass:cel = _swig_property(_wcs.WorldCoor_cel_get, _wcs.WorldCoor_cel_set)
    __swig_setmethods__["prj"] = _wcs.WorldCoor_prj_set
    __swig_getmethods__["prj"] = _wcs.WorldCoor_prj_get
    if _newclass:prj = _swig_property(_wcs.WorldCoor_prj_get, _wcs.WorldCoor_prj_set)
    __swig_setmethods__["lngcor"] = _wcs.WorldCoor_lngcor_set
    __swig_getmethods__["lngcor"] = _wcs.WorldCoor_lngcor_get
    if _newclass:lngcor = _swig_property(_wcs.WorldCoor_lngcor_get, _wcs.WorldCoor_lngcor_set)
    __swig_setmethods__["latcor"] = _wcs.WorldCoor_latcor_set
    __swig_getmethods__["latcor"] = _wcs.WorldCoor_latcor_get
    if _newclass:latcor = _swig_property(_wcs.WorldCoor_latcor_get, _wcs.WorldCoor_latcor_set)
    __swig_setmethods__["distcode"] = _wcs.WorldCoor_distcode_set
    __swig_getmethods__["distcode"] = _wcs.WorldCoor_distcode_get
    if _newclass:distcode = _swig_property(_wcs.WorldCoor_distcode_get, _wcs.WorldCoor_distcode_set)
    __swig_setmethods__["distort"] = _wcs.WorldCoor_distort_set
    __swig_getmethods__["distort"] = _wcs.WorldCoor_distort_get
    if _newclass:distort = _swig_property(_wcs.WorldCoor_distort_get, _wcs.WorldCoor_distort_set)
    __swig_setmethods__["command_format"] = _wcs.WorldCoor_command_format_set
    __swig_getmethods__["command_format"] = _wcs.WorldCoor_command_format_get
    if _newclass:command_format = _swig_property(_wcs.WorldCoor_command_format_get, _wcs.WorldCoor_command_format_set)
    __swig_setmethods__["ltm"] = _wcs.WorldCoor_ltm_set
    __swig_getmethods__["ltm"] = _wcs.WorldCoor_ltm_get
    if _newclass:ltm = _swig_property(_wcs.WorldCoor_ltm_get, _wcs.WorldCoor_ltm_set)
    __swig_setmethods__["ltv"] = _wcs.WorldCoor_ltv_set
    __swig_getmethods__["ltv"] = _wcs.WorldCoor_ltv_get
    if _newclass:ltv = _swig_property(_wcs.WorldCoor_ltv_get, _wcs.WorldCoor_ltv_set)
    __swig_setmethods__["idpix"] = _wcs.WorldCoor_idpix_set
    __swig_getmethods__["idpix"] = _wcs.WorldCoor_idpix_get
    if _newclass:idpix = _swig_property(_wcs.WorldCoor_idpix_get, _wcs.WorldCoor_idpix_set)
    __swig_setmethods__["ndpix"] = _wcs.WorldCoor_ndpix_set
    __swig_getmethods__["ndpix"] = _wcs.WorldCoor_ndpix_get
    if _newclass:ndpix = _swig_property(_wcs.WorldCoor_ndpix_get, _wcs.WorldCoor_ndpix_set)
    __swig_setmethods__["wcs"] = _wcs.WorldCoor_wcs_set
    __swig_getmethods__["wcs"] = _wcs.WorldCoor_wcs_get
    if _newclass:wcs = _swig_property(_wcs.WorldCoor_wcs_get, _wcs.WorldCoor_wcs_set)
    __swig_setmethods__["wcsdep"] = _wcs.WorldCoor_wcsdep_set
    __swig_getmethods__["wcsdep"] = _wcs.WorldCoor_wcsdep_get
    if _newclass:wcsdep = _swig_property(_wcs.WorldCoor_wcsdep_get, _wcs.WorldCoor_wcsdep_set)
    __swig_setmethods__["wcsname"] = _wcs.WorldCoor_wcsname_set
    __swig_getmethods__["wcsname"] = _wcs.WorldCoor_wcsname_get
    if _newclass:wcsname = _swig_property(_wcs.WorldCoor_wcsname_get, _wcs.WorldCoor_wcsname_set)
    __swig_setmethods__["wcschar"] = _wcs.WorldCoor_wcschar_set
    __swig_getmethods__["wcschar"] = _wcs.WorldCoor_wcschar_get
    if _newclass:wcschar = _swig_property(_wcs.WorldCoor_wcschar_get, _wcs.WorldCoor_wcschar_set)
    __swig_setmethods__["logwcs"] = _wcs.WorldCoor_logwcs_set
    __swig_getmethods__["logwcs"] = _wcs.WorldCoor_logwcs_get
    if _newclass:logwcs = _swig_property(_wcs.WorldCoor_logwcs_get, _wcs.WorldCoor_logwcs_set)
    def __init__(self): 
        """__init__(self) -> WorldCoor"""
        this = _wcs.new_WorldCoor()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _wcs.delete_WorldCoor
    __del__ = lambda self : None;
WorldCoor_swigregister = _wcs.WorldCoor_swigregister
WorldCoor_swigregister(WorldCoor)

# This file is compatible with both classic and new-style classes.





# -*- coding: utf-8 -*-
#File: setup.py
#Created: Sat Dec 15 19:40:30 2012
#Last Change: Sat Dec 15 19:42:45 2012

import os
import glob
from distutils.core import setup
from distutils.command.build_ext import build_ext
from distutils.extension import Extension
import distutils.ccompiler
import distutils.command.config
import distutils.sysconfig
from pkg_resources import require

topDir = os.getcwd()
sourceDir = "PyWCSTools"+os.path.sep+"wcssubs-3.9.5"+os.path.sep

#oFiles=glob.glob(sourceDir+"*.o")
#print oFiles
oFiles = ['PyWCSTools/wcssubs-3.9.5/cel.o', 'PyWCSTools/wcssubs-3.9.5/wcs.o',
    'PyWCSTools/wcssubs-3.9.5/proj.o', 'PyWCSTools/wcssubs-3.9.5/distort.o',
    'PyWCSTools/wcssubs-3.9.5/wcsinit.o', 'PyWCSTools/wcssubs-3.9.5/wcslib.o',
    'PyWCSTools/wcssubs-3.9.5/poly.o', 'PyWCSTools/wcssubs-3.9.5/platepos.o',
    'PyWCSTools/wcssubs-3.9.5/zpxpos.o', 'PyWCSTools/wcssubs-3.9.5/iget.o',
    'PyWCSTools/wcssubs-3.9.5/imio.o', 'PyWCSTools/wcssubs-3.9.5/dsspos.o',
    'PyWCSTools/wcssubs-3.9.5/tnxpos.o', 'PyWCSTools/wcssubs-3.9.5/wcscon.o',
    'PyWCSTools/wcssubs-3.9.5/fitsfile.o',
    'PyWCSTools/wcssubs-3.9.5/dateutil.o',
    'PyWCSTools/wcssubs-3.9.5/imhfile.o', 'PyWCSTools/wcssubs-3.9.5/lin.o',
    'PyWCSTools/wcssubs-3.9.5/fileutil.o',
    'PyWCSTools/wcssubs-3.9.5/wcstrig.o',
    'PyWCSTools/wcssubs-3.9.5/sph.o',
    'PyWCSTools/wcssubs-3.9.5/worldpos.o', 'PyWCSTools/wcssubs-3.9.5/hget.o',
    'PyWCSTools/wcssubs-3.9.5/hput.o']

exampleScripts = glob.glob("scripts"+os.path.sep+"*.py")

class build_PyWCSTools_ext(build_ext):

    def build_extensions(self):

        os.chdir(sourceDir)

        # This line is tough to make match the style guide
        cc =distutils.ccompiler.new_compiler(
            distutils.ccompiler.get_default_compiler())
        distutils.command.config.customize_compiler(cc)

        # Suppress warnings from compiling WCSTools wcssubs-3.9.5
        if "-Wstrict-prototypes" in cc.compiler_so:
            cc.compiler_so.pop(cc.compiler_so.index("-Wstrict-prototypes"))
        if "-Wall" in cc.compiler_so:
            cc.compiler_so.pop(cc.compiler_so.index("-Wall"))

        WCSToolsCFiles = glob.glob("*.c")
        WCSToolsCFiles.pop(WCSToolsCFiles.index("wcs_wrap.c"))
        WCSToolsCFiles.pop(WCSToolsCFiles.index("wcscon_wrap.c"))
        cc.compile(WCSToolsCFiles)

        os.chdir(topDir)

        build_ext.build_extensions(self)

setup(name='astLib',
    version='0.11.5',
    url='https://astlib.readthedocs.io',
    author='Matt Hilton & Steven Boada',
    author_email='matt.hilton@mykolab.com',
    classifiers=['Development Status :: 5 - Production/Stable',
            'Environment :: Console',
            'Intended Audience :: Science/Research',
            'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
            'Natural Language :: English',
            'Operating System :: POSIX',
            'Programming Language :: Python',
            'Topic :: Scientific/Engineering :: Astronomy',
            'Topic :: Software Development :: Libraries'],
    description='A set of python modules for producing simple plots, statistics, common calculations, coordinate conversions, and manipulating FITS images with World Coordinate System (WCS) information.',
    long_description="""astLib is a set of Python modules that provides some tools for research astronomers. It can be
used for simple plots, statistics, common calculations, coordinate conversions, and manipulating FITS images
with World Coordinate System (WCS) information through PyWCSTools - a simple wrapping of WCSTools by Jessica Mink.
PyWCSTools is distributed (and developed) as part of astLib.""",
    packages=['astLib', 'PyWCSTools'],
    package_data={'astLib': ['data/*']},
    cmdclass={"build_ext": build_PyWCSTools_ext},
    scripts=exampleScripts,
    ext_modules=[
        Extension('PyWCSTools._wcscon', [sourceDir+"wcscon_wrap.c"],
        extra_objects=oFiles),
        Extension('PyWCSTools._wcs', [sourceDir+"wcs_wrap.c"],
        extra_objects=oFiles)
    ]
	)
